@@ -32,6 +32,7 @@
 #include <Rcpp/Reference.h>
 #include <Rcpp/clone.h>
 #include <Rcpp/grow.h>
+#include <Rcpp/lgrow.h>
 #include <Rcpp/Dimension.h>
 
 #include <Rcpp/Symbol.h>
@@ -56,13 +57,19 @@
 #include <Rcpp/Formula.h>
 #include <Rcpp/DataFrame.h>
 
-//  #define RCPP_NEW_DATE_DATETIME_VECTORS 1
+#include <Rcpp/exceptions_impl.h>
+
+#if !defined(RCPP_FORCE_OLD_DATE_DATETIME_VECTORS)
+  #define RCPP_NEW_DATE_DATETIME_VECTORS 1
+#endif
 #include <Rcpp/date_datetime/date_datetime.h>
 
 #include <Rcpp/Na_Proxy.h>
 
+#ifndef RCPP_NO_MODULES
 #include <Rcpp/Module.h>
 #include <Rcpp/InternalFunction.h>
+#endif
 
 #include <Rcpp/Nullable.h>
 
