@@ -1,9 +1,7 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
-/* :tabSize=4:indentSize=4:noTabs=false:folding=explicit:collapseFolds=1: */
-//
+
 // caster.h: Rcpp R/C++ interface class library --
 //
-// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2026 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -26,9 +24,9 @@
 namespace Rcpp{
 namespace internal{
 
-template <typename FROM, typename TO> TO caster(FROM from){
+template <typename FROM, typename TO> TO caster(FROM from){ // #nocov start
 	return static_cast<TO>(from) ;
-}
+} 														    // #nocov end
 
 template <typename T>
 inline Rcomplex Rcomplex_caster( std::complex<T> from ){
@@ -67,4 +65,3 @@ inline std::complex<float>  caster<Rcomplex,std::complex<float> >( Rcomplex from
 }
 
 #endif
-
