@@ -1,8 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
-//
+
 // barrier.cpp: Rcpp R/C++ interface class library -- write barrier
 //
-// Copyright (C) 2010 - 2019  Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2020  Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2021 - 2026  Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
 //
 // This file is part of Rcpp.
 //
@@ -22,11 +22,15 @@
 #define COMPILING_RCPP
 
 #define USE_RINTERNALS
-#include <Rinternals.h>
-#include <Rcpp/barrier.h>
-#include "internal.h"
+
 #include <algorithm>
+#include <Rinternals.h>
+
+#include <Rcpp/barrier.h>
 #include <Rcpp/protection/Shield.h>
+#include <Rcpp/r/compat.h>
+
+#include "internal.h"
 
 // [[Rcpp::register]]
 SEXP get_string_elt(SEXP x, R_xlen_t i) {			// #nocov start
@@ -50,7 +54,8 @@ void char_set_string_elt(SEXP x, R_xlen_t i, const char* value) {
 
 // [[Rcpp::register]]
 SEXP* get_string_ptr(SEXP x) {
-    return STRING_PTR(x);
+    // TODO: should we deprecate this?
+    return const_cast<SEXP*>(RCPP_STRING_PTR(x));
 }
 
 // [[Rcpp::register]]
@@ -65,12 +70,14 @@ void set_vector_elt(SEXP x, R_xlen_t i, SEXP value) {
 
 // [[Rcpp::register]]
 SEXP* get_vector_ptr(SEXP x) {
-    return VECTOR_PTR(x);							// #nocov end
+    // TODO: should we deprecate this?
+    return const_cast<SEXP*>(RCPP_VECTOR_PTR(x));							// #nocov end
 }
 
 // [[Rcpp::register]]
 void* dataptr(SEXP x) {
-    return DATAPTR(x);
+    // DATAPTR_RO was introduced with R 3.5.0
+    return const_cast<void*>(DATAPTR_RO(x));
 }
 
 // [[Rcpp::register]]
@@ -88,6 +95,47 @@ static SEXP Rcpp_cache = R_NilValue;
 #define RCPP_HASH_CACHE_INITIAL_SIZE 1024
 #endif
 
+namespace Rcpp {
+static SEXP Rcpp_precious = R_NilValue;
+// [[Rcpp::register]]
+void Rcpp_precious_init() {
+    Rcpp_precious = CONS(R_NilValue, R_NilValue);   // set up
+	R_PreserveObject(Rcpp_precious); 			    // and protect
+}
+// [[Rcpp::register]]
+void Rcpp_precious_teardown() {						// #nocov start
+    R_ReleaseObject(Rcpp_precious);                 // release resource
+}													// #nocov end
+// [[Rcpp::register]]
+SEXP Rcpp_precious_preserve(SEXP object) {
+    if (object == R_NilValue) {
+        return R_NilValue;							// #nocov
+    }
+    PROTECT(object);
+    SEXP cell = PROTECT(CONS(Rcpp_precious, CDR(Rcpp_precious)));
+    SET_TAG(cell, object);
+    SETCDR(Rcpp_precious, cell);
+    if (CDR(cell) != R_NilValue) {
+        SETCAR(CDR(cell), cell);
+    }
+    UNPROTECT(2);
+    return cell;
+}
+// [[Rcpp::register]]
+void Rcpp_precious_remove(SEXP token) {
+    if (token == R_NilValue || TYPEOF(token) != LISTSXP) {
+        return;
+    }
+    SET_TAG(token, R_NilValue);
+    SEXP before = CAR(token);
+    SEXP after = CDR(token);
+    SETCDR(before, after);
+    if (after != R_NilValue) {
+        SETCAR(after, before);
+    }
+}
+}
+
 // only used for debugging
 SEXP get_rcpp_cache() {
     if (! Rcpp_cache_know) {
@@ -97,7 +145,11 @@ SEXP get_rcpp_cache() {
         Rcpp::Shield<SEXP> call(Rf_lang2(getNamespaceSym, RcppString));
         Rcpp::Shield<SEXP> RCPP(Rf_eval(call, R_GlobalEnv));
 
+#if R_VERSION < R_Version(4,5,0)
         Rcpp_cache = Rf_findVarInFrame(RCPP, Rf_install(".rcpp_cache"));
+#else
+        Rcpp_cache = R_getVar(Rf_install(".rcpp_cache"), RCPP, TRUE);
+#endif
         Rcpp_cache_know = true;
     }
     return Rcpp_cache;
